@@ -8,12 +8,12 @@ import os
 class TestSettings(TestCase):
     def test_defaults(self):
         s = Settings()
-        self.assertEquals(s.TIMEZONE, global_settings.TIMEZONE)
+        self.assertEqual(s.TIMEZONE, global_settings.TIMEZONE)
 
     def test_as_dict(self):
         s = Settings()
         d = s.as_dict()
-        self.assertEquals(d["TIMEZONE"], global_settings.TIMEZONE)
+        self.assertEqual(d["TIMEZONE"], global_settings.TIMEZONE)
 
     def test_add_module(self):
         s = Settings()
@@ -22,7 +22,7 @@ class TestSettings(TestCase):
         s.add_module(os)
 
         # Merging a module add all uppercase symbols
-        self.assertEquals(s.PRIO_USER, os.PRIO_USER)
+        self.assertEqual(s.PRIO_USER, os.PRIO_USER)
 
         # And ignores all lowercase ones
         self.assertFalse(hasattr(s, "getuid"))
@@ -33,6 +33,6 @@ class TestSettings(TestCase):
 
         s.load(datafile_abspath("settings.py"))
 
-        self.assertEquals(s.UPPERCASE, True)
+        self.assertEqual(s.UPPERCASE, True)
         self.assertFalse(hasattr(s, "lowercase"))
         self.assertFalse(hasattr(s, "os"))
